==> ajaxplorer-4.2.3.tbz: www/ajaxplorer/plugins/access.ajxp_conf/i18n/fr.php <==
<?php
/*
 * Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
 * This file is part of AjaXplorer.
 *
 * AjaXplorer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * AjaXplorer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The latest code can be found at <http://www.ajaxplorer.info/>.
 */
$mess=array(
"1" => "Données de configuration",
"2" => "Utilisateurs",
"3" => "Dépôts",
"4" => "Journal",
"5" => "Diagnostique",
"6" => "Nom",
"7" => "Administrateur",
"8" => "Nom du dépôt",
"9" => "Type d'accès",
"10" => "Métadonnées",
"11" => "Ajouter une source",
"12" => "Plugin Meta",
"13" => "Etes vous sur de vouloir supprimer cette source?",
"14" => "Oui",
"15" => "Non",
"16" => "Date du fichier",
"17" => "Date",
"18" => "I.P.",
"19" => "Niveau",
"20" => "Utilisateur",
"21" => "Action",
"22" => "Paramêtres",
"23" => "Nom du test",
"24" => "Résultat",
"25" => "Accès aux dépôts",
"26" => "Changer le mot de passe",
"27" => "Droit d'admin",
"28" => "L'utilisateur est administrateur?",
"29" => "Lire",
"30" => "Ecrire",
"32" => "Plugin du dépôt",
"33" => "Chargement...",
"34" => "Etes vous sur de vouloir effacer cet utilisateur? Cette opération est irréversible!",
"35" => "Etes vous sur de vouloir effacer ce dépôt? Cette opération est irréversible!",
"36" => "Des champs obligatoires ne sont pas remplis!",
"37" => "Attention les deux mots de passe diffèrent!",
"38" => "Veuillez remplir le champ login!",
"39" => "Veuillez remplir les deux champs password!",
"40" => "Veuillez cocher la case pour confirmer!",
"41" => "Options",
"42" => "Veuillez choisir un driver!",
"43" => "L'utilisateur existe, veuillez choisir un autre identifiant",
"44" => "L'utilisateur a été créé avec succès",
"45" => "Droit d'administration modifié pour l'utilisateur ",
"46" => "Droit d'accès modifié pour l'utilisateur ",
"47" => "Les données ont été sauvées pour l'utilisateur ",
"48" => "Le mot de passe a été modifié pour ",
"49" => "Impossible de changer le mot de passe",
"50" => "Erreur : un dépôt avec le même nom existe déjà.",
"51" => "Le répertoire conf n'est pas accessible en écriture.",
"52" => "Le dépôt a été créé.",
"53" => "Erreur lors de la modification du dépôt.",
"54" => "Le dépôt a été modifié.",
"55" => "Attention, pour l'instant vous ne pouvez ajouter qu'une seule instance de chaque plugin méta.",
"56" => "La source de métadonnées a été ajoutée.",
"57" => "La source de métadonnées a été supprimée.",
"58" => "La source de métadonnées a été modifiée.",
"59" => "Le dépôt a été supprimé",
"60" => "L'utilisateur a été supprimé",
"61" => "Mauvais arguments!",
"62" => "Résumé des droits",
"63" => "Tous",
"64" => "Les droits ont été changés pour le rôle ",
"65" => "Le rôle existe, choisissez un autre nom!",
"66" => "Le rôle a été créé",
"67" => "Impossible de trouver le rôle ",
"68" => "Le rôlé a été supprimé",
"69" => "Rôles",
"70" => "Rôles Utilisateur",
"71" => "Rôles disponibles",
"72" => "Glissez/Déposez les rôles pour les assigner à l'utilisateur",
"73" => "Le rôle a été ajouté à l'utilisateur ",
"74" => "Le rôle a été enlevé à l'utilisateur ",
"75" => "Nouveau rôle",
"role_access" => "ô",
"76" => "Identifiant",
"77" => "Contrôle d'accès",
"78" => "Données Personnelles",
"79" => "Dépot",
"80" => "Précisez les droits d'accès pour cet utilisateur  (Click on a repository label if you wish to make it the default repository when user logs in)",
"81" => "Données spécifiques aux dépôts",
"82" => "Edition en groupe des utilisateurs",
"83" => "Glissez/Déposez les rôles pour les assigner aux utilisateurs sélectionnés (les utilisateurs partagés ne seront pas pris en compte)",
"84" => "Rôles utilisateurs",
"85" => "Filtrage manuel des actions",
"86" => "Liste d'actions qui seront désactivées pour ce rôle, quelque soit le droit d'accès associé.",
"87" => "Les actions ont été mises à jour pour ce rôle.",
"88" => "Ce dépot est défini dans le fichier de configuration, il n'est pas possible de mettre à jour les métadonnées via l'interface.",
"89" => "Données spécifiques de l'utilisateur",
"90" => "Dépôt",
"91" => "Modèle",
"92" => "Créer un nouveau modèle",
"93" => "Edition",
"94" => "Edition en masse",
"95" => "Choisir un libellé et un driver pour accèder aux données (vérifiez les différentes sections qui contiennent des champs obligatoires, vous pouvez passer la souris sur les labels pour avoir plus d'infos).",
"96" => "Choisir un libellé et un driver, puis choisir les champs que vous voulez pré-remplir pour constituer ce modèle. Vous pouvez cocher des champs et les laisser vide.",
"repository_access_key" => "D",
"97" => "Plugin options successfully updated",
"98" => "Options Principales",
"99" => "Extensions",
"100" => "Options communes pour les '%s'",
"101" => "Nom",
"102" => "Identifiant",
"103" => "Description",
"104" => "Actif",
"105" => "Vérification",
"106" => "Identifiant unique",
"107" => "Configuration du plugin",
"108" => "Documentation",
"109" => "Configurations Globales",
"110" => "Dépôts & Utilisateurs",
"111" => "Logs & Autres données",
"112" => "<b>Appliquer ce rôle par défaut</b> à tous les nouveaux utilisateurs.",
"113" => "Le rôle a été modifié avec succès",
"114" => "Defaut",
"115" => "Schema",
"116" => "Nom du modèle",
"117" => "Plugin d'accès",
/* END SENTENCE */
);
?>

==> ajaxplorer-5.0.1.tbz: www/ajaxplorer/plugins/access.ajxp_conf/i18n/fr.php <==
<?php
/*
* Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
* This file is part of AjaXplorer.
*
* AjaXplorer is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* AjaXplorer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
* along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
*
* The latest code can be found at <http://www.ajaxplorer.info/>.
*/
$mess=array(
"1" => "Données de configuration",
"2" => "Utilisateurs & Groupes",
"3" => "Dépôts",
"4" => "Journal",
"5" => "Diagnostique",
"6" => "Nom",
"7" => "Administrateur",
"8" => "Nom du dépôt",
"9" => "Type d'accès",
"10" => "Métadonnées",
"11" => "Ajouter une source",
"12" => "Plugin Meta",
"13" => "Etes vous sur de vouloir supprimer cette source?",
"14" => "Oui",
"15" => "Non",
"16" => "Date du fichier",
"17" => "Date",
"18" => "I.P.",
"19" => "Niveau",
"20" => "Utilisateur",
"21" => "Action",
"22" => "Paramêtres",
"23" => "Nom du test",
"24" => "Résultat",
"25" => "Accès aux dépôts",
"26" => "Changer le mot de passe",
"27" => "Droit d'admin",
"28" => "L'utilisateur est administrateur?",
"29" => "Lire",
"30" => "Ecrire",
"32" => "Plugin du dépôt",
"33" => "Chargement...",
"34" => "Etes vous sur de vouloir effacer cet utilisateur? Cette opération est irréversible!",
"35" => "Etes vous sur de vouloir effacer ce dépôt? Cette opération est irréversible!",
"36" => "Des champs obligatoires ne sont pas remplis!",
"37" => "Attention les deux mots de passe diffèrent!",
"38" => "Veuillez remplir le champ login!",
"39" => "Veuillez remplir les deux champs password!",
"40" => "Veuillez cocher la case pour confirmer!",
"41" => "Options",
"42" => "Veuillez choisir un driver!",
"43" => "L'utilisateur existe, veuillez choisir un autre identifiant",
"44" => "L'utilisateur a été créé avec succès",
"45" => "Droit d'administration modifié pour l'utilisateur ",
"46" => "Droit d'accès modifié pour l'utilisateur ",
"47" => "Les données ont été sauvées pour l'utilisateur ",
"48" => "Le mot de passe a été modifié pour ",
"49" => "Impossible de changer le mot de passe",
"50" => "Erreur : un dépôt avec le même nom existe déjà.",
"51" => "Le répertoire conf n'est pas accessible en écriture.",
"52" => "Le dépôt a été créé.",
"53" => "Erreur lors de la modification du dépôt.",
"54" => "Le dépôt a été modifié.",
"55" => "Attention, pour l'instant vous ne pouvez ajouter qu'une seule instance de chaque plugin méta.",
"56" => "La source de métadonnées a été ajoutée.",
"57" => "La source de métadonnées a été supprimée.",
"58" => "La source de métadonnées a été modifiée.",
"59" => "Le dépôt a été supprimé",
"60" => "L'utilisateur a été supprimé",
"61" => "Mauvais arguments!",
"62" => "Résumé des droits",
"63" => "Tous",
"64" => "Les droits ont été changés pour le rôle ",
"65" => "Le rôle existe, choisissez un autre nom!",
"66" => "Le rôle a été créé",
"67" => "Impossible de trouver le rôle ",
"68" => "Le rôlé a été supprimé",
"69" => "Rôles",
"70" => "Rôles Utilisateur",
"71" => "Rôles disponibles",
"72" => "Glissez/Déposez les rôles pour les assigner à l'utilisateur",
"73" => "Le rôle a été ajouté à l'utilisateur ",
"74" => "Le rôle a été enlevé à l'utilisateur ",
"75" => "Nouveau rôle",
"role_access" => "ô",
"76" => "Identifiant",
"77" => "Contrôle d'accès",
"78" => "Données Personnelles",
"79" => "Dépot",
"80" => "Précisez les droits d'accès pour cet utilisateur  (Click on a repository label if you wish to make it the default repository when user logs in)",
"81" => "Données spécifiques aux dépôts",
"82" => "Edition en groupe des utilisateurs",
"83" => "Glissez/Déposez les rôles pour les assigner aux utilisateurs sélectionnés (les utilisateurs partagés ne seront pas pris en compte)",
"84" => "Rôles utilisateurs",
"85" => "Filtrage manuel des actions",
"86" => "Liste d'actions qui seront désactivées pour ce rôle, quelque soit le droit d'accès associé.",
"87" => "Les actions ont été mises à jour pour ce rôle.",
"88" => "Ce dépot est défini dans le fichier de configuration, il n'est pas possible de mettre à jour les métadonnées via l'interface.",
"89" => "Données spécifiques de l'utilisateur",
"90" => "Nouveau dépôt",
"91" => "Nouveau modèle",
"92" => "Créer un nouveau modèle",
"93" => "Edition",
"94" => "Edition en masse",
"95" => "Choisir un libellé et un driver pour accèder aux données (vérifiez les différentes sections qui contiennent des champs obligatoires, vous pouvez passer la souris sur les labels pour avoir plus d'infos).",
"96" => "Choisir un libellé et un driver, puis choisir les champs que vous voulez pré-remplir pour constituer ce modèle. Vous pouvez cocher des champs et les laisser vide.",
"repository_access_key" => "D",
"97" => "Plugin options successfully updated",
"98" => "Options Principales",
"99" => "Extensions",
"100" => "Options communes pour les '%s'",
"101" => "Nom",
"102" => "Identifiant",
"103" => "Description",
"104" => "Actif",
"105" => "Vérification",
"106" => "Identifiant unique",
"107" => "Configuration du plugin",
"108" => "Documentation",
"109" => "Configurations Globales",
"110" => "Dépôts & Utilisateurs",
"111" => "Logs & Autres données",
"112" => "<b>Appliquer ce rôle par défaut</b> à tous les nouveaux utilisateurs.",
"113" => "Le rôle a été modifié avec succès",
"114" => "Defaut",
"115" => "Schema",
"116" => "Nom du modèle",
"117" => "Plugin d'accès",
"118" => "Nouveau Groupe",
"group_access" => "G",
"119" => "Set user group",
/* END SENTENCE */
);
?>
